# vadr

**DOI:** [10.5281/zenodo.13323320](https://doi.org/10.5281/zenodo.13323320)

## Available Versions
- **Version 1.6.4**
  - [Download](https://zenodo.org/record/13323321/files/vadr_1.6.4.img)
  - **MD5:** `ed748fb3cccbb488b49fe05c18ec2bab`
  - **DOI:** [10.5281/zenodo.13323321](https://doi.org/10.5281/zenodo.13323321)
  - **Size:** 793.17 MB
  - **Binaries:** 0 available

## Binaries (1 total)

```v-annotate.pl,v-build.pl,fasta-trim-terminal-ambigs.pl```
